is_terminal: Determine the type of terminal

is_kittyR Documentation

Determine the type of terminal

Description

Determine the type of terminal

Usage

is_kitty()

is_ghostty()

is_nvim()

is_vim()

is_tmux()

Details

These functions try to detect if R is running in a given terminal.

Value

Returns TRUE if R is running in a given terminal and FALSE otherwise.

Examples

if (is_kitty()) {
  cat("Yeeh, you are running kitty!")
}
if (is_ghostty()) {
  cat("Yeeh, you are running ghostty!")
}


terminalgraphics documentation built on May 1, 2026, 5:07 p.m.