| png2tgp | R Documentation |
Dump a PNG image to the terminal using the Terminal Graphics Protocol
png2tgp(filename)
filename |
filename of the PNG image |
The Terminal Graphics Protocol is not supported by many Terminal Emulators. The most notable terminal emulator supporting the protocol is Kitty.
Called for it's side effect of writing the image to the terminal (standard
out). Returns NULL invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.