| term_background | R Documentation |
Get the colors used in the terminal
term_background()
term_foreground()
term_palette()
Getting the color palette used in the terminal is terminal specific.
Currently only the kitty terminal is supported. For other terminals default
colors are returned. Unless set using options (see below).
When the option term_background is set, that is returned by
term_background(). The same with the options term_foreground
and term_palette by term_foreground() and term_palette()
respectively.
term_background and term_foreground will return a length 1
vector with a color. term_palette will return a vector of colors.
kitty_colors for the functions returning the specific colors
used in the kitty terminal. Also see term_color_mode which is
used to determine the color mode.
term_background()
options(term_background = "black", term_foreground = "white",
term_palette = grDevices::hcl.colors("Pastel1", n = 9),
term_col = TRUE)
# term_col enables automatic use of the colors by tgp() and sixel()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.