| is_kitty | R Documentation |
Determine the type of terminal
is_kitty()
is_ghostty()
is_nvim()
is_vim()
is_tmux()
These functions try to detect if R is running in a given terminal.
Returns TRUE if R is running in a given terminal
and FALSE otherwise.
if (is_kitty()) {
cat("Yeeh, you are running kitty!")
}
if (is_ghostty()) {
cat("Yeeh, you are running ghostty!")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.